@@ -907,6 +907,7 @@ def test_test_cli(mocker, tuxsuite_config):
         tests=[],
         timeouts={},
         boot_args=None,
+        dtb=None,
         wait_for=None,
     )
     assert wait_for_object.call_count == 1
@@ -938,6 +939,7 @@ def test_test_cli(mocker, tuxsuite_config):
         tests=["ltp-smoke"],
         timeouts={},
         boot_args=None,
+        dtb=None,
         wait_for=None,
     )
     assert wait_for_object.call_count == 1
@@ -968,6 +970,7 @@ def test_test_cli(mocker, tuxsuite_config):
         tests=["ltp-smoke"],
         timeouts={},
         boot_args=None,
+        dtb=None,
         wait_for="mybuilduid",
     )
     assert wait_for_object.call_count == 1
@@ -998,6 +1001,7 @@ def test_test_cli(mocker, tuxsuite_config):
         tests=[],
         timeouts={"deploy": 1, "boot": 2},
         boot_args=None,
+        dtb=None,
         wait_for=None,
     )
     assert wait_for_object.call_count == 1
@@ -1037,6 +1041,7 @@ def test_test_cli(mocker, tuxsuite_config):
         tests=["lldb"],
         timeouts={},
         boot_args=None,
+        dtb=None,
         wait_for=None,
     )
     assert wait_for_object.call_count == 1
@@ -1640,8 +1645,9 @@ def test_patch_series_error(mocker, tuxsuite_config):
             "--patch-series=httpsucks.patch",
         ],
     )
-    assert result.exit_code == 2
-    assert "Error: Invalid value for '-p' / '--patch-series'" in result.output
+
+    assert result.exit_code == 1
+    assert FileNotFoundError == result.exc_info[0]
 
     mocker.resetall()
     # invalid patch file
@@ -1656,8 +1662,8 @@ def test_patch_series_error(mocker, tuxsuite_config):
             "--patch-series=/tmp/invalidpatch",
         ],
     )
-    assert result.exit_code == 2
-    assert "Error: Invalid value for '-p' / '--patch-series'" in result.output
+    assert result.exit_code == 1
+    assert FileNotFoundError == result.exc_info[0]
 
 
 def test_patch_series_pass(mocker, sample_patch_tgz, sample_patch_mbx, tuxsuite_config):
